@@ -1,6 +1,8 @@
 from .alphaquery import AlphaQuery
 from .barchart import BarChart
 from .exceptions import HttpException
+from .finviz import FinViz
+from .stockanalysis import StockAnalysis
 from .stocktwits import StockTwits
 from .tipranks import TipRanks
 from .yahoo import Yahoo
